@@ -5,15 +5,15 @@ use strict;
 use warnings;
 use utf8;
 
+# Target reasonably old Perl
+use 5.006;
+
 # Include required modules
 use Carp;
 use English '-no_match_vars';
 
-# Target reasonably old Perl
-use 5.006;
-
 # Declare package version
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Patterns to match elements of the LRC file; these are somewhat tolerant
 our %RE = (
@@ -272,7 +272,7 @@ Music::Lyrics::LRC - Manipulate LRC karaoke timed lyrics files
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 DESCRIPTION
 
@@ -431,11 +431,11 @@ Perl 5.6 or newer
 
 =item *
 
-C<Carp>
+L<Carp|Carp>
 
 =item *
 
-C<English>
+L<English|English>
 
 =back
 
